x = 3  # input
y = 5  # input
print('What is your name?')  # ignore
z = x + y  # output
z = 100000   # ignore